pub trait AddContext<I: Stream, C = &'static str>: Sized {
// Provided method
fn add_context(
self,
_input: &I,
_token_start: &<I as Stream>::Checkpoint,
_context: C,
) -> Self { ... }
}Expand description
Used by Parser::context to add custom data to error while backtracking
May be implemented multiple times for different kinds of context.
Provided Methods
Sourcefn add_context(
self,
_input: &I,
_token_start: &<I as Stream>::Checkpoint,
_context: C,
) -> Self
fn add_context( self, _input: &I, _token_start: &<I as Stream>::Checkpoint, _context: C, ) -> Self
Append to an existing error custom data
This is used mainly by Parser::context, to add user friendly information
to errors when backtracking through a parse tree
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl<I: Stream, C> AddContext<I, C> for ()
Implementors
impl<C, I: Stream> AddContext<I, C> for ContextError<C>
impl<I, C> AddContext<I, C> for TreeError<I, C>
Available on crate feature
std only.